 /*
 * file      : src/callbacks.c
 * project   : tm
 * with      : Gtk-2
 *
 * copyright : (C) 2012 by Claude BULIN
 *
 * TM - Edition des heures de travail / Edition of working hours
 * GNU General Public License
 * 
 * This file is part of TM.
 * 
 * TM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * TM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with TM.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
	#define gettext_noop(x) (x) 
#endif

#include <gtk/gtk.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_tm/lib.h"
#endif

#include "global.h"
#include "configuser.h"
#include "win_new_year.h"
#include "fileselect.h"
#include "win_export.h"
#include "win_adj_time.h"
#include "callbacks.h"



VAR_CALLBACKS VarCallbacks = {
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL
	};
	

VAR_DRAW VarDraw = {
	NULL,
	NULL,
	0,
	0,
	1.0,
	0.0,
	0.0,
	TRUE,
	FALSE,
	NULL,
	0,
	"FreeSans",
	9.0,
	12.0
	};
	



// 
// CREATION FORMAT A4 * p_TotalPages
// PARAM:
// 	gint p_TotalPages:	1 .. n +1
// 
void callbacks_alloc_page( gint p_TotalPages )
{
	gint	Height;
	
	VarDraw.TotalPages = p_TotalPages;
	
	if( NULL != VarDraw.image ) {
		// REMOVE IMAGE
		cairo_surface_destroy( VarDraw.image );
		VarDraw.image = NULL;
	}
	VarDraw.BoolSaveToFile  = FALSE;
	
	Height = (841 * VarDraw.TotalPages);
	
	VarDraw.image = cairo_image_surface_create(
				CAIRO_FORMAT_ARGB32,
				595,		// A4	width
				Height		// A4	height
				);
	VarDraw.image_width  = cairo_image_surface_get_width( VarDraw.image );
	VarDraw.image_height = cairo_image_surface_get_height( VarDraw.image );
}
// 
// INIT DE LA SURFACE DE DESSIN
// 
void on_drawingarea_draw_realize( GtkWidget *widget, gpointer user_data )
{
	VarDraw.AdrDrawingarea  = widget;
	// VarDraw.scale           = SCALE_MIN;
	VarDraw.scale           = Config.ValueScale;
	VarDraw.BoolScaleAdjust = Config.BoolScaleAdjust;
	callbacks_alloc_page( 1 );
}
// 
// 
// 
void callbacks_button_new_year( gboolean BoolAccept )
{
	gchar	*Str = NULL;
	gint	RetDayOfYear;
	
	// g_print( "BoolAccept = %s\n", BoolAccept ? "TRUE" : "FALSE" );
	if( FALSE == BoolAccept ) {
		// gboolean libutils_test_write( gchar *path )
		// gboolean libutils_test_file_exist( Config.PathNameFileBase )
		// gboolean libutils_test_dir_exist (gchar *File)
		// if( TRUE == libutils_test_file_exist( Config.PathNameFileBase )
	}
		
	// STOCKAGE DU NOUVEAU PATH_NAME_FILE
	edit_set_pathnamefile( Config.PathNameFileNEWBase );
	
	gtk_label_set_use_markup( GTK_LABEL(GLADE_GET_OBJECT("label_new_year")), TRUE );
	Str = g_strdup_printf( _("<b>Edition de l'annee [ %d ] pour le fichier [ %s ]</b>"), VarEdit.YearEdit, edit_get_namefile( Config.PathNameFileBase ) );
	gtk_label_set_label( GTK_LABEL(GLADE_GET_OBJECT("label_new_year")), Str );
	g_free( Str );
	Str = NULL;
	
	VarEdit.BoolReady = TRUE;
	file_alloc_struct();
	RetDayOfYear = edit_select_new_year();
	edit_set_datas_to_spinbuttons( RetDayOfYear );
	edit_set_flag_buttons();
}
// 
// 
// 
void on_button_new_year_clicked( GtkButton *button, gpointer user_data )
{
	file_save_struct( FORCE_SAVE_FILE );
	WinNewYear_open( callbacks_button_new_year );
}
// 
// 
// 
void callbacks_button_open_year( gchar *p_path )
{
	// OPEN FILENAME
	if( TRUE == file_read( p_path )) {
		
		gchar	*Str = NULL;
		gint	RetDayOfYear;

		// STOCKAGE DU NOUVEAU PATH_NAME_FILE
		edit_set_pathnamefile( p_path );
		
		gtk_label_set_use_markup( GTK_LABEL(GLADE_GET_OBJECT("label_new_year")), TRUE );
		Str = g_strdup_printf( _("<b>Edition de l'annee [ %d ] pour le fichier [ %s ]</b>"), VarEdit.YearEdit, edit_get_namefile( Config.PathNameFileBase ) );
		gtk_label_set_label( GTK_LABEL(GLADE_GET_OBJECT("label_new_year")), Str );
		g_free( Str );
		Str = NULL;
		
		VarEdit.BoolReady = TRUE;
		RetDayOfYear = edit_select_new_year();
		edit_set_datas_to_spinbuttons( RetDayOfYear );
		edit_set_flag_buttons();
	}
	else {
		PRINT("-----------------------REMOVE");
		file_remove_struct_year();
		VarEdit.BoolReady = FALSE;
		draw_year();
	}
}
void on_button_open_year_clicked( GtkButton *button, gpointer user_data )
{
	file_save_struct( FORCE_SAVE_FILE );
	fileselect( _("Choix d'un fichier"), GTK_FILE_CHOOSER_ACTION_OPEN,  callbacks_button_open_year, Config.PathNameFileBase, WindMain );
}
// 
// 
// 
void on_button_export_year_clicked( GtkButton *button, gpointer user_data )
{
	// EditYear_put_weeks();
	WinExport_open( export_file );
}
// 
// 
// 
void on_button_init_base_year_clicked( GtkButton *button, gpointer user_data )
{
	WinAdjTime_open();
}
// 
// RETRECIS LA SURFACE DE DESSIN
// 
void on_button_size_moins_clicked( GtkButton *button, gpointer user_data )
{
	if( NULL != VarDraw.AdrDrawingarea ) {
		VarDraw.BoolScaleAdjust = FALSE;
		
		if( VarDraw.scale > _VALUE_ ) VarDraw.scale -= _VALUE_;
		if( VarDraw.scale < _VALUE_ ) VarDraw.scale = _VALUE_;
		
		draw_year();
		draw_set_size_request();
	}
}
// 
// SURFACE DE DESSIN A 100%
// 
void on_button_size_normal_clicked( GtkButton *button, gpointer user_data )
{
	if( NULL != VarDraw.AdrDrawingarea ) {
		VarDraw.BoolScaleAdjust = FALSE;
		
		VarDraw.scale = 1.0;
		
		draw_year();
		draw_set_size_request();
	}
}
// 
// AUGMENTE LA SURFACE DE DESSIN
// 
void on_button_size_plus_clicked( GtkButton *button, gpointer user_data )
{
	if( NULL != VarDraw.AdrDrawingarea ) {
		VarDraw.BoolScaleAdjust = FALSE;
		
		if( VarDraw.scale < 6.0 ) VarDraw.scale += _VALUE_;
		if( VarDraw.scale > 6.0 ) VarDraw.scale = 6.0;

		draw_year();
		draw_set_size_request();
	}
}
// 
// AJUSTEMENT DE LA SURFACE DE DESSIN AVEC LA FENETRE
// 
void on_button_size_adjust_clicked( GtkButton *button, gpointer user_data )
{
	if( NULL != VarDraw.AdrDrawingarea ) {
		VarDraw.BoolScaleAdjust = TRUE;
		draw_year();
		draw_set_size_request();
	}
}
// 
// LE MOIS A CHANGE
// 
void on_calendar_tm_month_changed( GtkCalendar *calendar, gpointer user_data )
{
	// PRINT_FUNC_LF();
}
// 
// LE JOUR A CHANGE
// 
void on_calendar_tm_day_selected( GtkCalendar *calendar, gpointer user_data )
{
	guint 	year, month, day;
	
	gtk_calendar_get_date( VarCallbacks.Adr_Calendar, &year, &month, &day );
	VarEdit.DayOfYear = -1;
	if( TRUE == VarEdit.BoolReady && year == VarEdit.YearEdit ) {
		
		GDate	*DateHeap;
		// Seeking the number of days for the structure
		DateHeap = g_date_new ();
		g_date_set_year( DateHeap, year );
		g_date_set_month( DateHeap, month +1 );
		g_date_set_day( DateHeap, day );
		VarEdit.DayOfYear = g_date_get_day_of_year( DateHeap );
		VarEdit.DayOfYear --;
		g_date_free( DateHeap );
		edit_set_datas_to_spinbuttons( VarEdit.DayOfYear );
		file_save_struct( NO_FORCE_SAVE_FILE );
	}
	file_make_list();
	draw_year();
	edit_set_flag_buttons();
}
// 
// INIT DU CALENDRIER
// 
void on_calendar_tm_realize( GtkWidget *widget, gpointer user_data )
{
	gint	Year;
	gint	Month;
	gint	Day;
	
	VarCallbacks.Adr_Calendar = GTK_CALENDAR(widget);
	
	// draw_set_adr_call_func_extern( EditYear_draw_page );
	
	libutils_get_DMY( &Day, &Month, &Year );
	
	gtk_calendar_select_month( GTK_CALENDAR(VarCallbacks.Adr_Calendar), Month -1, Year );
	gtk_calendar_select_day( GTK_CALENDAR(VarCallbacks.Adr_Calendar), Day );
	
	// EditYear_set_new_year( Year );
	VarEdit.YearEdit = Year;
	
	VarEdit.DayAdjust = (VAR_EDIT_DAY *)g_malloc0( sizeof(VAR_EDIT_DAY) * MAX_DAY_ADJUST );

	// LUNDI
	// Config.HoursMonday[ 0 ]
	VarEdit.DayAdjust[ 0 ].MatinDebut = Config.HoursMonday[ 0 ];
	VarEdit.DayAdjust[ 0 ].MatinFin   = Config.HoursMonday[ 1 ];
	VarEdit.DayAdjust[ 0 ].SoirDebut  = Config.HoursMonday[ 2 ];
	VarEdit.DayAdjust[ 0 ].SoirFin    = Config.HoursMonday[ 3 ];
	// MARDI
	// Config.HoursTuesday[ 0 ]
	VarEdit.DayAdjust[ 1 ].MatinDebut = Config.HoursTuesday[ 0 ];
	VarEdit.DayAdjust[ 1 ].MatinFin   = Config.HoursTuesday[ 1 ];
	VarEdit.DayAdjust[ 1 ].SoirDebut  = Config.HoursTuesday[ 2 ];
	VarEdit.DayAdjust[ 1 ].SoirFin    = Config.HoursTuesday[ 3 ];
	// MERCREDI
	// Config.HoursWednesday[ 0 ]
	VarEdit.DayAdjust[ 2 ].MatinDebut = Config.HoursWednesday[ 0 ];
	VarEdit.DayAdjust[ 2 ].MatinFin   = Config.HoursWednesday[ 1 ];
	VarEdit.DayAdjust[ 2 ].SoirDebut  = Config.HoursWednesday[ 2 ];
	VarEdit.DayAdjust[ 2 ].SoirFin    = Config.HoursWednesday[ 3 ];
	// JEUDI
	// Config.HoursThursday[ 0 ]
	VarEdit.DayAdjust[ 3 ].MatinDebut = Config.HoursThursday[ 0 ];
	VarEdit.DayAdjust[ 3 ].MatinFin   = Config.HoursThursday[ 1 ];
	VarEdit.DayAdjust[ 3 ].SoirDebut  = Config.HoursThursday[ 2 ];
	VarEdit.DayAdjust[ 3 ].SoirFin    = Config.HoursThursday[ 3 ];
	// VENDREDI
	// Config.HoursFriday[ 0 ]
	VarEdit.DayAdjust[ 4 ].MatinDebut = Config.HoursFriday[ 0 ];
	VarEdit.DayAdjust[ 4 ].MatinFin   = Config.HoursFriday[ 1 ];
	VarEdit.DayAdjust[ 4 ].SoirDebut  = Config.HoursFriday[ 2 ];
	VarEdit.DayAdjust[ 4 ].SoirFin    = Config.HoursFriday[ 3 ];
	// SAMEDI
	// Config.HoursSaturday[ 0 ]
	VarEdit.DayAdjust[ 5 ].MatinDebut = Config.HoursSaturday[ 0 ];
	VarEdit.DayAdjust[ 5 ].MatinFin   = Config.HoursSaturday[ 1 ];
	VarEdit.DayAdjust[ 5 ].SoirDebut  = Config.HoursSaturday[ 2 ];
	VarEdit.DayAdjust[ 5 ].SoirFin    = Config.HoursSaturday[ 3 ];
	// DIMANCHE
	// Config.HoursSunday[ 0 ]
	VarEdit.DayAdjust[ 6 ].MatinDebut = Config.HoursSunday[ 0 ];
	VarEdit.DayAdjust[ 6 ].MatinFin   = Config.HoursSunday[ 1 ];
	VarEdit.DayAdjust[ 6 ].SoirDebut  = Config.HoursSunday[ 2 ];
	VarEdit.DayAdjust[ 6 ].SoirFin    = Config.HoursSunday[ 3 ];
}
// 
// EXPOSE EVENT
// PARAM:
// RETURN:
// 
gboolean on_drawingarea_draw_expose_event( GtkWidget *widget, GdkEventExpose *event, gpointer user_data )
{
	// PRINT_FUNC_LF();
	draw_paint( NULL );
	return( TRUE );
}
// 
// NOTIFY EVENT
// PARAM:
// RETURN:
// 
gboolean on_drawingarea_draw_motion_notify_event( GtkWidget *drawingarea, GdkEventMotion *event, gpointer user_data )
{
	// PRINT_FUNC_LF();
	return( TRUE );
}
// 
// INIT DU CALENDRIER AVEC LE JOUR ACTUEL
// PARAM:
// RETURN:
// 
/*
void callbacks_init_calendar( void )
{
	gint 	year, month, day;

	libutils_get_DMY( &day, &month, &year );
	month --;
	g_print( ">year = %04d   month = %02d   day = %02d         ", year, month, day );
	g_print( "[ %s %d %s %d ]\n", libutils_get_str_weekday( day, month+1, year ), day, libutils_get_str_month( month), year );
	gtk_calendar_select_month( VarCallbacks.Adr_Calendar, month, year );
	gtk_calendar_select_day( VarCallbacks.Adr_Calendar, day );
}
*/




















